"""

SqlCarve Module
---------------

Ce module est la sclasse d'initialisation de la librairie
"""

from sqlcarve.validator.validator import *
from sqlcarve.main import analyse